@@ -11,14 +11,11 @@ use strict;
 use warnings;
 
 package Dist::Zilla::Config::Slicer;
-{
-  $Dist::Zilla::Config::Slicer::VERSION = '0.200';
-}
-BEGIN {
-  $Dist::Zilla::Config::Slicer::AUTHORITY = 'cpan:RWSTAUNER';
-}
-# ABSTRACT: Config::MVP::Slicer customized for Dist::Zilla
+# git description: v0.200-6-g8420185
 
+our $AUTHORITY = 'cpan:RWSTAUNER';
+# ABSTRACT: Config::MVP::Slicer customized for Dist::Zilla
+$Dist::Zilla::Config::Slicer::VERSION = '0.201';
 use Config::MVP::Slicer ();
 use Dist::Zilla::Util 4 ();
 use Moose;
@@ -34,22 +31,22 @@ no Moose;
 __PACKAGE__->meta->make_immutable;
 1;
 
-
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =for :stopwords Randy Stauner ACKNOWLEDGEMENTS cpan testmatrix url annocpan anno bugtracker
 rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
-=encoding utf-8
-
 =head1 NAME
 
 Dist::Zilla::Config::Slicer - Config::MVP::Slicer customized for Dist::Zilla
 
 =head1 VERSION
 
-version 0.200
+version 0.201
 
 =head1 SYNOPSIS
 
@@ -111,58 +108,18 @@ in addition to those websites please use your favorite search engine to discover
 
 =item *
 
-Search CPAN
+MetaCPAN
 
-The default CPAN search engine, useful to view POD in HTML format.
+A modern, open-source CPAN search engine, useful to view POD in HTML format.
 
-L<http://search.cpan.org/dist/Dist-Zilla-Config-Slicer>
-
-=item *
-
-RT: CPAN's Bug Tracker
-
-The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Dist-Zilla-Config-Slicer>
-
-=item *
-
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/Dist-Zilla-Config-Slicer>
-
-=item *
-
-CPAN Testers
-
-The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
-
-L<http://www.cpantesters.org/distro/D/Dist-Zilla-Config-Slicer>
-
-=item *
-
-CPAN Testers Matrix
-
-The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.
-
-L<http://matrix.cpantesters.org/?dist=Dist-Zilla-Config-Slicer>
-
-=item *
-
-CPAN Testers Dependencies
-
-The CPAN Testers Dependencies is a website that shows a chart of the test results of all dependencies for a distribution.
-
-L<http://deps.cpantesters.org/?module=Dist::Zilla::Config::Slicer>
+L<http://metacpan.org/release/Dist-Zilla-Config-Slicer>
 
 =back
 
 =head2 Bugs / Feature Requests
 
 Please report any bugs or feature requests by email to C<bug-dist-zilla-config-slicer at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Dist-Zilla-Config-Slicer>. You will be automatically notified of any
+the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=Dist-Zilla-Config-Slicer>. You will be automatically notified of any
 progress on the request by the system.
 
 =head2 Source Code
@@ -184,4 +141,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
