@@ -11,14 +11,9 @@ use strict;
 use warnings;
 
 package Dist::Zilla::Role::PluginBundle::Config::Slicer;
-{
-  $Dist::Zilla::Role::PluginBundle::Config::Slicer::VERSION = '0.200';
-}
-BEGIN {
-  $Dist::Zilla::Role::PluginBundle::Config::Slicer::AUTHORITY = 'cpan:RWSTAUNER';
-}
+our $AUTHORITY = 'cpan:RWSTAUNER';
 # ABSTRACT: Pass Portions of Bundle Config to Plugins
-
+$Dist::Zilla::Role::PluginBundle::Config::Slicer::VERSION = '0.201';
 use Dist::Zilla::Config::Slicer ();
 use Moose::Role;
 
@@ -42,13 +37,13 @@ around bundle_config => sub {
 
 1;
 
-
 __END__
+
 =pod
 
-=for :stopwords Randy Stauner ACKNOWLEDGEMENTS
+=encoding UTF-8
 
-=encoding utf-8
+=for :stopwords Randy Stauner ACKNOWLEDGEMENTS
 
 =head1 NAME
 
@@ -56,7 +51,7 @@ Dist::Zilla::Role::PluginBundle::Config::Slicer - Pass Portions of Bundle Config
 
 =head1 VERSION
 
-version 0.200
+version 0.201
 
 =head1 SYNOPSIS
 
@@ -80,7 +75,11 @@ and merge them transparently.
   [@MyBundle]
   option = 1
   Included::Plugin.attribute = overwrite value
-  AnotherPlug.array[] = append value
+  AnotherPlug.array[0] = append value
+  AnotherPlug.array[1] = append another value
+
+See L<Config::MVP::Slicer/CONFIGURATION SYNTAX> for details
+on how the configurations are handled.
 
 This role adds a method modifier to C<bundle_config>,
 which is the method that the root C<PluginBundle> role requires,
@@ -137,4 +136,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
